#  [![jackal-11-24-v2-32-inverted.png](https://i.postimg.cc/wBPhM5Lv/jackal-11-24-v2-32-inverted.png)]()  CODEBABEL

## royalprint: 0.0.1 🐍
### description / descrição :
~~~
{EN}

roaylprint is perfect for simplifying the information that needs to go to the console, similar to printing in C++ command cout, PHP echo, log("Hi"), go("Hello ..."), cout("whoami?"), puts ("She Knows")... and more.

{PTBR}

roaylprint é perfeita para simplificar as informações que precisam ir para o console, com similaridade de impressão em C++ comando cout, PHP echo, log("Oi"), go("Olá ..."), cout("whoami?"), puts("She Knows")... e mais. 
~~~

![](https://img.shields.io/pypi/pyversions/abess)
![](https://img.shields.io/badge/license-MIT-blue)
![](https://img.shields.io/badge/-Linux-grey?logo=linux)
![](https://shields.io/badge/MacOS--9cf?logo=Apple&style=social)
![](https://img.shields.io/badge/Windows-10%20&%2011-blue)

[![royalprint.png](https://i.postimg.cc/HLxCjz9S/royalprint.png)]()

## 🌐 Content / Conteúdo
* [Installation](#installation)
* [All print formats](#formats)
* [Basic use](#basic)
* [Complete use](#complete)
* [Change log](#changelog)

### installation
## 💻 Installation / Instalação:
pip windows
> `pip install royalprint`

pip3 linux
> `pip3 install royalprint`

python poetry
> `poetry add royalprint`

python cargo uv
> `uv add royalprint`

### how to use / como usar :
> use go minimum sintax
~~~python
# codebabel go
from royalprint import go

say_my_name = "SayMyName."
go(say_my_name)

#> SayMyName.
~~~

> codebabel show
~~~python
# codebabel show
from royalprint import go

se_eu_largar_o_freio = "Vai dar mais valor pra mim."
show(se_eu_largar_o_freio)

#> Vai dar mais valor pra mim.
~~~

> use PHP echo
~~~python
# PHP echo
from royalprint import echo

my_name_is = "What?"
echo(my_name_is)

#> What?
~~~

> Angular xPrint
~~~python
# Angular xPrint
from royalprint import xFlask

show_this = "Do your jumps!"
xFlask(show_this)

#> Do your jumps!
~~~
### formats
### all print formats / todos os formatos
~~~
go
log
show
echo
puts
display
putline
cout
printf
printin
println

xFlask
xDjango
xFastAPI
xBrython
~~~
### basic
> basic use
~~~python
# easy pease fela / uso básico fela
from royalprint import (go, log)

msg_box = "I am tea pot!"
log(msg_box); # simple console message > ...
go("nengue");  # simple console message > ...
~~~
### complete
> complete use
~~~python
# easy pease use/ uso básico fela
from royalprint import *

msg_box = "I am tea pot!";

# basic...
log(msg_box); # [scm] simple console message > ...

# Aesthetic Print...
go(msg_box);       # codebabel go
show(msg_box);     # codebabel show
echo(msg_box);     # php echo
puts(msg_box);     # Ruby puts
display(msg_box);  # cobol display
putline(msg_box); # ada putline
cout(msg_box);     # c++ cout <
printf(msg_box);   # c printf
printin(msg_box);  # scala printin
println(msg_box);  # java println

# Aesthetic xPrint Thematic
xFlask(msg_box);     # Vue xPrint
xDjango(msg_box);   # React xPrint
xBrython(msg_box);  # Svelte xPrint
xFastAPI(msg_box); # Angular xPrint
~~~
### changelog
## 🚨 Change Log
|Version| Version Name | Upgrade Latency |
|-------|--------------|-----------------|
| 0.0.1 |  royalprint  |    START LIB    |

## 💜 Thank's 🧡
~~~
{EN}
Thank you for using the royalprint library.
see ya!

{PTBR}
Valeu por usar a biblioteca royalprint.
tmj!
~~~
© Copyright 2026, Codebabel royalprint cross-language library.